import React, { useEffect, useState } from 'react';
import './App.css';
import axios from 'axios';

import {VersionComponent, InfoComponent} from './Components.tsx';

import { Grid, Tab, Tabs, Paper, Typography, CircularProgress } from '@mui/material';

import { ThemeProvider, createTheme } from '@mui/material/styles';


let theme = createTheme({
  palette: {
    primary: {
      main: '#049a9b',
    }
  },
});




const fetchDataSgi = async (streamlineSgiId) => {
  try {
    const res = await axios.get("https://cc.streamline.pt/api/applications/findOne", 
    {
      params: {
        filter: {
          where: {
            id: streamlineSgiId
          },
          include: ["modules", {
            relation: "versions",
            scope: {
              include: "module",
              order: "version DESC"
            }
          }]
        }
      }
    });

    let data = res.data;
    let modulesSgi = data.modules;    
    let versionsSgi = data.versions;

    return { modulesSgi, versionsSgi }; // Return both modules and versions

  } catch (error) {
    // Handle errors if any
    console.error('Error fetching data:', error);
    throw error;
  }
};


const fetchDataApp = async (streamlineAppId) => {
  try {
    const res = await axios.get("https://cc.streamline.pt/api/applications/findOne", 
    {
      params: {
        filter: {
          where: {
            id: streamlineAppId
          },
          include: ["modules", {
            relation: "versions",
            scope: {
              include: "module",
              order: "version DESC"
            }
          }]
        }
      }
    });

    let data = res.data;

    return data

  } catch (error) {
    // Handle errors if any
    console.error('Error fetching data:', error);
    throw error;
  }
};



function App() {

  const streamlineSgiId = "60a288ed33320700119606f9";
  const streamlineAppId = "6082b67f1e0f13001133287b";

  const [value, setValue] = useState(0);  
  const [selectedVersion, setSelectedVersion] = useState(null);
  const [modulesData, setModulesData] = useState({ modules: [], versions: [] });
  const [appData, setAppData] = useState({ modules: [], versions: [] });

  const [loading, setLoading] = useState(true);


  const handleChange = (event, newValue) => {
    setValue(newValue);
    setSelectedVersion(null); // Reset selectedVersion when switching tabs
  };

  useEffect(() => {
    const fetchModules = async () => {
      try {
        const { modulesSgi, versionsSgi } = await fetchDataSgi(streamlineSgiId);
        setModulesData({ modules: modulesSgi, versions: versionsSgi }); // Set the modules and versions in the state

        const appData = await fetchDataApp(streamlineAppId);
        setAppData(appData);

      } catch (error) {
        console.error('Error fetching modules:', error);          // Handle errors if any

      } finally {
        setLoading(false); // Set loading state to false when the fetch operation is complete
      }
    };

    fetchModules(); // Call the function to fetch modules

  }, [streamlineSgiId]);



  return (
    <ThemeProvider theme={theme}>
      
    
    <div className="App">
      <Typography variant="h3" sx={{ fontWeight: 'bold', marginBottom: '10px' }}>
        Histórico de versões
      </Typography>


         {loading ? (
          // Display a loading circular progress while data is being fetched
          <div sx={{ display: 'flex', justifyContent: 'center', alignItems: 'center', height: '200%' }}>
            <CircularProgress />
          </div>

        ) : (
          <div className="WhiteWindow">

          <Grid container>

           {/*----TAB SELECTION AREA----------------------------------------------*/}
            <Grid item md={12}>
              <Tabs value={value} onChange={handleChange}>
                <Tab label="SISTEMA DE GESTÃO INTEGRADO (WEB)" />
                <Tab label="APLICAÇÃO MÓVEL" />
              </Tabs>
            </Grid>
            
            {/*-------INFO AREA----------------------------------------*/}
            <Grid container sx={{ margin: '5px', padding: '5px', marginBottom: '20px' }}>
          
              {/*-------HISTORICO VERSOES----------------------------------------*/}
              <Grid item md={6} sx={{ padding: "10px" }}>
                <Paper>
                  {value === 0 && <VersionComponent message={modulesData} setSelectedVersion={setSelectedVersion}/>}
                  {value === 1 && <VersionComponent message={appData} setSelectedVersion={setSelectedVersion} />}
                </Paper>
              </Grid>

               {/*-------MORE INFO GRIDS (Info and improvements)----------------------------------------*/}
              <Grid item md={6} sx={{ padding: "10px" }}>
                <Paper>
                  {value === 0 && <InfoComponent modules={modulesData} version={selectedVersion} />}
                  {value === 1 && <InfoComponent modules={appData} version={selectedVersion} />}
                </Paper>
              </Grid>
            </Grid>
          </Grid>
          </div>
        )}

    </div>
    </ThemeProvider>
  );
}


export default App;
